#ifndef NT2_INCLUDE_FUNCTIONS_ISHERMITIAN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISHERMITIAN_HPP_INCLUDED

#include <nt2/predicates/include/functions/ishermitian.hpp>

#endif
